# Generated by Django 4.1.3 on 2023-04-13 09:49

from django.db import migrations, models
from openbook_common.enums import VisibilityType
from openbook_communities.models import Task


# The following enums have changed to uppercase, and existing values should be updated.
def updateTaskEnumFields(model, db_alias):
    for obj in model.objects.using(db_alias):
        visibility = VisibilityType.MEMBERS
        if obj.visibility != 'members':
            visibility = VisibilityType.PUBLIC

        location_type = Task.LocationType.REMOTE
        if obj.location_type == 'hybrid':
            location_type = Task.LocationType.HYBRID
        if obj.location_type == 'onsite':
            location_type = Task.LocationType.ONSITE

        regularity = Task.Regularity.REGULARLY
        if obj.regularity == 'project-based':
            regularity = Task.Regularity.PROJECT_BASED
        if obj.regularity == 'one-time':
            regularity = Task.Regularity.ONE_TIME

        obj.visibility = visibility
        obj.location_type = location_type
        obj.regularity = regularity
        obj.save()


class Migration(migrations.Migration):
    dependencies = [
        ("openbook_communities", "0024_alter_task_visibility"),
    ]

    def forwards_func(apps, schema_editor):
        TaskModel = apps.get_model("openbook_communities.Task")
        db_alias = schema_editor.connection.alias
        updateTaskEnumFields(TaskModel, db_alias)

    operations = [
        migrations.AlterField(
            model_name="task",
            name="location_type",
            field=models.CharField(
                choices=[("HYBRID", "Hybrid"), ("REMOTE", "Remote"), ("ONSITE", "Onsite")],
                default="REMOTE",
                max_length=6,
            ),
        ),
        migrations.AlterField(
            model_name="task",
            name="regularity",
            field=models.CharField(
                choices=[("REGULARLY", "Regularly"), ("PROJECT_BASED", "Project Based"), ("ONE_TIME", "One Time")],
                max_length=13,
            ),
        ),
        migrations.AlterField(
            model_name="task",
            name="visibility",
            field=models.CharField(
                choices=[("MEMBERS", "Members"), ("PUBLIC", "Public")], default="PUBLIC", max_length=12
            ),
        ),
        migrations.RunPython(forwards_func,),
    ]
